@@ -339,6 +339,16 @@ void MixMaxRng::flatArray(const int size, double* vect )
    for (int i=0; i<size; ++i) { vect[i] = flat(); }
 }
 
+MixMaxRng::operator double()
+{
+  return flat();
+}
+
+MixMaxRng::operator float()
+{
+  return float( flat() );
+}
+
 MixMaxRng::operator unsigned int()
 {
    return static_cast<unsigned int>(get_next());
@@ -706,7 +716,7 @@ myuint_t MixMaxRng::apply_bigskip( myuint_t* Vout, myuint_t* Vin, myID_t cluster
 
 myuint_t MixMaxRng::modadd(myuint_t foo, myuint_t bar)
 {
-#if defined(__x86_64__) &&  defined(__GNUC__) && (!defined(__ICC))
+#if defined(__x86_64__) && defined(__GNUC__) && (!defined(__ICC))
    //#warning Using assembler routine in modadd
    myuint_t out;
    /* Assembler trick suggested by Andrzej Görlich     */
